manrododex.CLI package
======================

Submodules
----------

manrododex.CLI.argparse module
------------------------------

.. automodule:: manrododex.CLI.argparse
   :members:
   :undoc-members:
   :show-inheritance:

manrododex.CLI.downloading\_args module
---------------------------------------

.. automodule:: manrododex.CLI.downloading_args
   :members:
   :undoc-members:
   :show-inheritance:

manrododex.CLI.general\_args module
-----------------------------------

.. automodule:: manrododex.CLI.general_args
   :members:
   :undoc-members:
   :show-inheritance:

manrododex.CLI.required\_args module
------------------------------------

.. automodule:: manrododex.CLI.required_args
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: manrododex.CLI
   :members:
   :undoc-members:
   :show-inheritance:
